<?xml version="1.0" ?><!DOCTYPE TS><TS language="hu" version="2.1">
<context>
    <name>ExpressionBar</name>
    <message>
        <source>Expression Error</source>
        <translation>Kifejezés hiba</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Dark theme</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Simple mode</source>
        <translation>Egyszerű mód</translation>
    </message>
    <message>
        <source>Scientific mode</source>
        <translation>Tudományos mód</translation>
    </message>
    <message>
        <source>Deepin Calculator</source>
        <translation>Deepin Számológép</translation>
    </message>
    <message>
        <source>Deepin Calculator is a simple and easy to use desktop calculator. It supports addition, subtraction, multiplication and division.</source>
        <translation>A Deepin Számológép egy letisztult és könnyen használható alkalmazás. Támogatja az összeadást, kivonást, szorzást és az osztást.</translation>
    </message>
</context>
<context>
    <name>SimpleListDelegate</name>
    <message>
        <source>Expression Error</source>
        <translation>Kifejezés hiba</translation>
    </message>
</context>
</TS>